package Task::Spark::Form;
our $VERSION = '0.03012607';



# ABSTRACT: All you need to start with Spark::Form

use strict;
use warnings;



1;


__END__
=pod

=head1 NAME

Task::Spark::Form - All you need to start with Spark::Form

=head1 VERSION

version 0.03012607

=head1 SYNOPSIS

    perl -MCPAN -e 'install Task::Spark::Form'

=cut

=pod

=head1 DESCRIPTION

The bare essentials of L<Spark::Form>, with everything
you'll probably ever want to use to do anything with it.

=head1 AUTHOR

Kent Fredric <kentnl@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2009 by Kent Fredric.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

